@@ -1,7 +1,8 @@
 package Net::Kubernetes::Resource;
 # ABSTRACT: Base class for all Net::Kubernetes::Resource objects.
-$Net::Kubernetes::Resource::VERSION = '0.23';
+$Net::Kubernetes::Resource::VERSION = '1.0';
 use Moose;
+use Clone qw(clone);
 
 with 'Net::Kubernetes::Role::APIAccess';
 
@@ -47,17 +48,17 @@ sub as_hashref
 {
 	my($self) = @_;
 
-        # It is possible for kuberentes to churn the resource version higher even if 
+        # It is possible for kuberentes to churn the resource version higher even if
         # you just refresh it and then attempt an update operation. Let's ignore it for now.
         my $metadata = $self->metadata;
         delete $metadata->{resourceVersion};
-	
-	return {
+
+	return clone({
 		inner(),
 		apiVersion=>$self->api_version,
 		kind=>$self->kind,
 		metadata=>$self->metadata
-	};
+	});
 }
 
 return 42;
@@ -74,7 +75,7 @@ Net::Kubernetes::Resource - Base class for all Net::Kubernetes::Resource objects
 
 =head1 VERSION
 
-version 0.23
+version 1.0
 
 =head1 METHODS
 
